@@ -1,7 +1,7 @@
 from functools import wraps
 
+from flask_minify.cache import MemoryCache
 from flask_minify.parsers import Parser
-from flask_minify.utils import get_optimized_hashing
 
 
 def minify(
@@ -9,6 +9,7 @@ def minify(
     js=False,
     cssless=False,
     cache=True,
+    caching_limit=2,
     fail_safe=True,
     parsers={},
 ):
@@ -24,6 +25,8 @@ def minify(
             enable minifying CSS/LESS content.
         cache: bool
             enable caching minifed response.
+        caching_limit: int
+            to limit the number of minified response variations.
         failsafe: bool
             silence encountered exceptions.
         parsers: dict
@@ -33,30 +36,21 @@ def minify(
     -------
         String of minified HTML content.
     """
-    hashing = get_optimized_hashing()
+    caching = MemoryCache(caching_limit if cache else 0)
     parser = Parser(parsers, fail_safe)
     parser.update_runtime_options(html, js, cssless)
 
     def decorator(function):
         @wraps(function)
         def wrapper(*args, **kwargs):
-            text = function(*args, **kwargs)
-            key = None
-            cache_key, cached = function.__dict__.get("minify", (None, None))
-            should_minify = isinstance(text, str) and any([html, js, cssless])
+            content = function(*args, **kwargs)
+            should_minify = isinstance(content, str) and any([html, js, cssless])
+            get_minified = lambda: parser.minify(content, "html")
 
-            if should_minify:
-                if cache:
-                    key = hashing(text).hexdigest()
+            if not should_minify:
+                return content
 
-                if cache_key != key or not cache:
-                    text = parser.minify(text, "html")
-
-                    if cache:
-                        function.__dict__["minify"] = (key, text)
-
-            should_return_cached = cache_key == key and cache and should_minify
-            return cached if should_return_cached else text
+            return caching.get_or_set(content, get_minified)
 
         return wrapper
 
